@@ -98,7 +98,7 @@ class CWUser(AnyEntity):
             prop = self._cw.execute(
                 'CWProperty X WHERE X pkey %(k)s, X for_user U, U eid %(u)s',
                 {'k': pkey, 'u': self.eid}).get_entity(0, 0)
-        except:
+        except Exception:
             kwargs = dict(pkey=unicode(pkey), value=value)
             if self.is_in_group('managers'):
                 kwargs['for_user'] = self
