@@ -76,7 +76,7 @@ class VRegistryTC(ViewSelectorTC):
             return
         try:
             self.assertSetEqual(content.keys(), expected)
-        except:
+        except Exception:
             print registry, sorted(expected), sorted(content.keys())
             print 'no more', [v for v in expected if not v in content.keys()]
             print 'missing', [v for v in content.keys() if not v in expected]
@@ -126,7 +126,6 @@ class VRegistryTC(ViewSelectorTC):
                               ('rsetxml', xmlrss.XMLRsetView),
                               ('rss', xmlrss.RSSView),
                               ('sameetypelist', baseviews.SameETypeListView),
-                              ('secondary', baseviews.SecondaryView),
                               ('security', management.SecurityManagementView),
                               ('table', tableview.TableView),
                               ('text', baseviews.TextView),
@@ -150,7 +149,6 @@ class VRegistryTC(ViewSelectorTC):
                               ('rsetxml', xmlrss.XMLRsetView),
                               ('rss', xmlrss.RSSView),
                               ('sameetypelist', baseviews.SameETypeListView),
-                              ('secondary', baseviews.SecondaryView),
                               ('security', management.SecurityManagementView),
                               ('table', tableview.TableView),
                               ('text', baseviews.TextView),
@@ -204,7 +202,6 @@ class VRegistryTC(ViewSelectorTC):
                               ('primary', primary.PrimaryView),] + RDFVIEWS + [
                               ('rsetxml', xmlrss.XMLRsetView),
                               ('rss', xmlrss.RSSView),
-                              ('secondary', baseviews.SecondaryView),
                               ('security', management.SecurityManagementView),
                               ('table', tableview.TableView),
                               ('text', baseviews.TextView),
@@ -240,7 +237,6 @@ class VRegistryTC(ViewSelectorTC):
                               ('rsetxml', xmlrss.XMLRsetView),
                               ('rss', xmlrss.RSSView),
                               ('sameetypelist', baseviews.SameETypeListView),
-                              ('secondary', baseviews.SecondaryView),
                               ('security', management.SecurityManagementView),
                               ('table', tableview.TableView),
                               ('text', baseviews.TextView),
@@ -468,7 +464,7 @@ class VRegistryTC(ViewSelectorTC):
         try:
             obj = self.vreg['views'].select(vid, req, rset=rset, **args)
             return obj.render(**args)
-        except:
+        except Exception:
             print vid, rset, args
             raise
 
